@@ -6,7 +6,7 @@ use common::sense;
 
 use Scalar::Util qw[];
 
-our $VERSION   = '0.002';
+our $VERSION   = '0.003';
 
 sub new
 {
@@ -14,7 +14,7 @@ sub new
 	
 	tie my @self, __PACKAGE__.'::Tie';
 	my $self = bless \@self, $class;
-	$JSON::JOM::Object::TIEMAP->{ Scalar::Util::refaddr(tied(@self)) } = $self;
+	$JSON::JOM::Node::TIEMAP->{ Scalar::Util::refaddr(tied(@self)) } = $self;
 	
 	$meta ||= {};
 	while (my ($k,$v) = each %$meta)
@@ -37,7 +37,7 @@ sub new
 
 sub can
 {
-	return JSON::JOM::Object::can(@_);
+	return JSON::JOM::Node::can(@_);
 }
 
 sub typeof
@@ -145,34 +145,8 @@ JSON::JOM::Array - represents an array in a JOM structure
 
 =head1 DESCRIPTION
 
-JOM arrays have the following built-in methods. Other methods are
-available in JOM plugins.
-
-=over 4
-
-=item * C<typeof> - returns the string 'ARRAY'.
-
-=item * C<rootNode> - a reference to the root node of the JOM structure.
-
-=item * C<isRootNode> - boolean; is this the root node of the JOM structure?
-
-=item * C<parentNode> - a reference to the parent of this node in the JOM structure.
-
-=item * C<nodePath> - a L<JSON::Path>-compatible string pointing to this node within the JOM structure.
-
-=item * C<nodeIndex> - the array index or object key of the parentNode where this node is located.
-
-=item * C<meta> - returns a hashref containing metadata about this node. This is intended for use by plugins.
-
-=back
-
-Note, the following should always be true for any JOM node C<$this>:
-
-   $this->isRootNode
-   or $this->parentNode->typeof eq 'ARRAY'
-      && $this->parentNode->[ $this->nodeIndex ] == $this
-   or $this->parentNode->typeof eq 'HASH'
-      && $this->parentNode->{ $this->nodeIndex } == $this
+JSON::JOM::Array represents an array structure in JSON. It is a subclass of
+JSON::JOM::Node.
 
 =head1 BUGS
 
@@ -180,7 +154,7 @@ Please report any bugs to L<http://rt.cpan.org/>.
 
 =head1 SEE ALSO
 
-L<JSON::JOM>, L<JSON::JOM::Plugins>.
+L<JSON::JOM>, L<JSON::JOM::Node>.
 
 =head1 AUTHOR
 
